@@ -35,10 +35,11 @@ import (
 )
 
 var (
-	flagYaml  bool
-	flagRaw   bool
-	flagSlurp bool
-	flagComp  bool // Echo autocomplete integration code.
+	flagYaml   bool
+	flagRaw    bool
+	flagSlurp  bool
+	flagComp   bool
+	flagStrict bool
 )
 
 func main() {
@@ -94,6 +95,8 @@ func main() {
 		case "-rs", "-sr":
 			flagRaw = true
 			flagSlurp = true
+		case "--strict":
+			flagStrict = true
 		default:
 			args = append(args, arg)
 		}
@@ -157,11 +160,11 @@ func main() {
 			os.Exit(1)
 			return
 		}
-		parser = NewJsonParser(bytes.NewReader(jsonBytes))
+		parser = NewJsonParser(bytes.NewReader(jsonBytes), flagStrict)
 	} else if flagRaw {
 		parser = NewLineParser(src)
 	} else {
-		parser = NewJsonParser(src)
+		parser = NewJsonParser(src, flagStrict)
 	}
 
 	if len(args) > 0 || flagSlurp {
@@ -183,6 +186,9 @@ func main() {
 		Background(lipgloss.Color("15")).
 		Foreground(lipgloss.Color("0"))
 
+	commandInput := textinput.New()
+	commandInput.Prompt = ":"
+
 	searchInput := textinput.New()
 	searchInput.Prompt = "/"
 
@@ -219,6 +225,7 @@ func main() {
 		fileName:        fileName,
 		digInput:        digInput,
 		gotoSymbolInput: gotoSymbolInput,
+		commandInput:    commandInput,
 		searchInput:     searchInput,
 		search:          newSearch(),
 		spinner:         spinnerModel,
@@ -245,6 +252,10 @@ func main() {
 					p.Send(eofMsg{})
 					break
 				}
+				if flagStrict {
+					p.Send(errorMsg{err: err})
+					break
+				}
 				textNode := parser.Recover()
 				p.Send(nodeMsg{node: textNode})
 			} else {
@@ -261,6 +272,10 @@ func main() {
 	if m.printOnExit {
 		fmt.Println(m.cursorValue())
 	}
+
+	if m.printErrorOnExit != nil {
+		fmt.Print(m.printErrorOnExit.Error())
+	}
 }
 
 type model struct {
@@ -279,6 +294,7 @@ type model struct {
 	fileName              string
 	digInput              textinput.Model
 	gotoSymbolInput       textinput.Model
+	commandInput          textinput.Model
 	searchInput           textinput.Model
 	search                *search
 	yank                  bool
@@ -287,6 +303,7 @@ type model struct {
 	showPreview           bool
 	preview               viewport.Model
 	printOnExit           bool
+	printErrorOnExit      error
 	spinner               spinner.Model
 	locationHistory       []location
 	locationIndex         int // position in locationHistory
@@ -304,6 +321,10 @@ type nodeMsg struct {
 	node *Node
 }
 
+type errorMsg struct {
+	err error
+}
+
 type eofMsg struct{}
 
 func (m *model) Init() tea.Cmd {
@@ -335,6 +356,10 @@ func (m *model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		m.eof = true
 		return m, nil
 
+	case errorMsg:
+		m.printErrorOnExit = msg.err
+		return m, tea.Quit
+
 	case nodeMsg:
 		if m.wrap {
 			Wrap(msg.node, m.viewWidth())
@@ -417,6 +442,9 @@ func (m *model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		if m.digInput.Focused() {
 			return m.handleDigKey(msg)
 		}
+		if m.commandInput.Focused() {
+			return m.handleGotoLineKey(msg)
+		}
 		if m.searchInput.Focused() {
 			return m.handleSearchKey(msg)
 		}
@@ -548,6 +576,26 @@ func (m *model) handlePreviewKey(msg tea.Msg) (tea.Model, tea.Cmd) {
 	return m, cmd
 }
 
+func (m *model) handleGotoLineKey(msg tea.KeyMsg) (tea.Model, tea.Cmd) {
+	var cmd tea.Cmd
+	switch {
+	case msg.Type == tea.KeyEscape:
+		m.commandInput.Blur()
+		m.commandInput.SetValue("")
+		m.showCursor = true
+
+	case msg.Type == tea.KeyEnter:
+		m.commandInput.Blur()
+		command := m.commandInput.Value()
+		m.commandInput.SetValue("")
+		return m.runCommand(command)
+
+	default:
+		m.commandInput, cmd = m.commandInput.Update(msg)
+	}
+	return m, cmd
+}
+
 func (m *model) handleSearchKey(msg tea.KeyMsg) (tea.Model, tea.Cmd) {
 	var cmd tea.Cmd
 	switch {
@@ -858,6 +906,11 @@ func (m *model) handleKey(msg tea.KeyMsg) (tea.Model, tea.Cmd) {
 			}
 		}
 
+	case key.Matches(msg, keyMap.CommandLine):
+		m.commandInput.CursorEnd()
+		m.commandInput.Width = m.termWidth - 2 // -1 for the prompt, -1 for the cursor
+		m.commandInput.Focus()
+
 	case key.Matches(msg, keyMap.Search):
 		m.searchInput.CursorEnd()
 		m.searchInput.Width = m.termWidth - 2 // -1 for the prompt, -1 for the cursor
@@ -1082,6 +1135,9 @@ func (m *model) viewHeight() int {
 	if m.gotoSymbolInput.Focused() {
 		return m.termHeight - 2
 	}
+	if m.commandInput.Focused() {
+		return m.termHeight - 2
+	}
 	if m.searchInput.Focused() || m.searchInput.Value() != "" {
 		return m.termHeight - 2
 	}
@@ -1193,7 +1249,7 @@ func (m *model) cursorValue() string {
 		if at.Chunk != "" && at.Value == "" {
 			at = parent
 		}
-		if at.Kind == Object || at.Kind == Array {
+		if len(at.Value) >= 1 && at.Value[0] == '}' || at.Value[0] == ']' {
 			at = parent
 		}
 	}
